@@ -174,6 +174,8 @@ class IWorkflow(Interface):
     A workflow is a "state machine" defined by a set of states and transitions.
     """
 
+    label = Attribute("Workflow label")
+
     initial_state = Attribute("Initial state")
 
     update_states = Set(title="Updatable states",
@@ -501,11 +503,16 @@ class IWorkflowPublicationInfo(Interface):
                            required=False,
                            readonly=True)
 
-    first_publication_date = Datetime(title=_("First publication date"),
-                                      description=_("First date at which content was accepted "
-                                                    "for publication"),
+    first_publication_date = Datetime(title=_("First version publication date"),
+                                      description=_("First date at which content version "
+                                                    "was accepted for publication"),
                                       required=False)
 
+    content_publication_date = Datetime(title=_("First content publication date"),
+                                        description=_("First date at which first content version "
+                                                      "was accepted for publication"),
+                                        required=False)
+
     publication_effective_date = Datetime(title=_("Publication start date"),
                                           description=_("Date from which content will be "
                                                         "visible"),
@@ -604,12 +611,3 @@ class IWorkflowCommentInfo(Interface):
     comment = Text(title=_("Comment"),
                    description=_("Comment associated with this operation"),
                    required=False)
-
-
-class IWorkflowManagementTask(Interface):
-    """Workflow management task marker interface
-
-    This interface is used to mark scheduler tasks (see PyAMS_scheduler) which are
-    used by some workflows which can provide a "future" publication date, and which
-    relies on task scheduler to do the actual publication.
-    """
